=== modified file 'computer-janitor-core/computerjanitor/plugin.py'
--- computer-janitor-core/computerjanitor/plugin.py	2009-02-05 18:55:51 +0000
+++ computer-janitor-core/computerjanitor/plugin.py	2009-02-13 10:00:25 +0000
@@ -31,6 +31,17 @@
     method for details.
     
     """
+
+    def get_condition(self):
+        if hasattr(self, "_condition"):
+            return self._condition
+        else:
+            return None
+            
+    def set_condition(self, condition):
+        self._condition = condition
+
+    condition = property(get_condition, set_condition)
     
     def set_application(self, app):
         """Set the Application instance this plugin belongs to.
@@ -124,7 +135,7 @@
         f.close()
         return module
 
-    def get_plugins(self, callback=None):
+    def get_plugins(self, condition=None, callback=None):
         """Return all plugins that have been found.
         
         If callback is specified, it is called after each plugin has
@@ -147,4 +158,5 @@
                     plugin.set_application(self._app)
                     self._plugins.append(plugin)
         
-        return self._plugins
+        return [p for p in self._plugins 
+                if p.condition == condition or condition == "*"]

=== modified file 'computer-janitor-core/computerjanitor/plugin_tests.py'
--- computer-janitor-core/computerjanitor/plugin_tests.py	2009-02-05 18:55:51 +0000
+++ computer-janitor-core/computerjanitor/plugin_tests.py	2009-02-13 10:00:25 +0000
@@ -40,6 +40,10 @@
         p.set_application("foo")
         self.assertEqual(p.app, "foo")
 
+    def testSetsRequiredConditionToNoneByDefault(self):
+        p = computerjanitor.Plugin()
+        self.assertEqual(p.condition, None)
+
 
 class PluginManagerTests(unittest.TestCase):
 
@@ -71,3 +75,30 @@
         self.callback_called = False
         pm.get_plugins(callback=self.callback)
         self.assert_(self.callback_called)
+
+
+class ConditionTests(unittest.TestCase):
+
+    def setUp(self):
+        self.pm = computerjanitor.PluginManager(None, ["testplugins"])
+
+        class White(computerjanitor.Plugin):
+            pass
+
+        class Red(computerjanitor.Plugin):
+            def __init__(self):
+                self.condition = "red"
+
+        self.white = White()
+        self.red = Red()
+        self.pm._plugins = [self.white, self.red]
+
+    def testReturnsOnlyConditionlessPluginByDefault(self):
+        self.assertEqual(self.pm.get_plugins(), [self.white])
+
+    def testReturnsOnlyRedPluginWhenConditionIsRed(self):
+        self.assertEqual(self.pm.get_plugins(condition="red"), [self.red])
+
+    def testReturnsEallPluginsWhenRequested(self):
+        self.assertEqual(set(self.pm.get_plugins(condition="*")),
+                         set([self.white, self.red]))

